@@ -21,6 +21,7 @@
  */
 
 #include <giomm/appinfo.h>
+#include <giomm/application.h>
 #include <giomm/asyncresult.h>
 #include <giomm/bufferedinputstream.h>
 #include <giomm/bufferedoutputstream.h>
@@ -28,7 +29,15 @@
 #include <giomm/contenttype.h>
 #include <giomm/datainputstream.h>
 #include <giomm/dataoutputstream.h>
-#include <giomm/desktopappinfo.h>
+#include <giomm/dbusauthobserver.h>
+#include <giomm/dbusconnection.h>
+#include <giomm/dbusmessage.h>
+#include <giomm/dbusmethodinvocation.h>
+#include <giomm/dbusownname.h>
+#include <giomm/dbusserver.h>
+#ifndef G_OS_WIN32
+# include <giomm/desktopappinfo.h>
+#endif
 #include <giomm/drive.h>
 #include <giomm/emblemedicon.h>
 #include <giomm/emblem.h>
@@ -48,7 +57,10 @@
 #include <giomm/filterinputstream.h>
 #include <giomm/filteroutputstream.h>
 #include <giomm/icon.h>
+#include <giomm/inetaddress.h>
+#include <giomm/inetsocketaddress.h>
 #include <giomm/init.h>
+#include <giomm/initable.h>
 #include <giomm/inputstream.h>
 #include <giomm/iostream.h>
 #include <giomm/loadableicon.h>
@@ -56,11 +68,30 @@
 #include <giomm/memoryoutputstream.h>
 #include <giomm/mount.h>
 #include <giomm/mountoperation.h>
+#include <giomm/networkaddress.h>
+#include <giomm/networkservice.h>
 #include <giomm/outputstream.h>
+#include <giomm/resolver.h>
 #include <giomm/seekable.h>
+#include <giomm/settings.h>
+#include <giomm/socket.h>
+#include <giomm/socketaddress.h>
+#include <giomm/socketaddressenumerator.h>
+#include <giomm/socketclient.h>
+#include <giomm/socketconnectable.h>
+#include <giomm/socketconnection.h>
+#include <giomm/socketcontrolmessage.h>
+#include <giomm/srvtarget.h>
+#include <giomm/tcpconnection.h>
 #include <giomm/themedicon.h>
-#include <giomm/unixinputstream.h>
-#include <giomm/unixoutputstream.h>
+#ifndef G_OS_WIN32
+# include <giomm/unixconnection.h>
+# include <giomm/unixcredentialsmessage.h>
+# include <giomm/unixfdlist.h>
+# include <giomm/unixfdmessage.h>
+# include <giomm/unixinputstream.h>
+# include <giomm/unixoutputstream.h>
+#endif
 #include <giomm/volume.h>
 #include <giomm/volumemonitor.h>
 
