@@ -13,12 +13,21 @@
 // #include the widget headers so that we can call the get_type() static methods:
 
 #include "appinfo.h"
+#include "application.h"
+#include "asyncinitable.h"
 #include "asyncresult.h"
 #include "bufferedinputstream.h"
 #include "bufferedoutputstream.h"
 #include "cancellable.h"
+#include "credentials.h"
 #include "datainputstream.h"
 #include "dataoutputstream.h"
+#include "dbusauthobserver.h"
+#include "dbusconnection.h"
+#include "dbusmessage.h"
+#include "dbusmethodinvocation.h"
+#include "dbusownname.h"
+#include "dbusserver.h"
 #include "drive.h"
 #include "emblem.h"
 #include "emblemedicon.h"
@@ -61,6 +70,7 @@
 #include "socketclient.h"
 #include "socketconnectable.h"
 #include "socketconnection.h"
+#include "socketcontrolmessage.h"
 #include "socketlistener.h"
 #include "socketservice.h"
 #include "srvtarget.h"
@@ -71,6 +81,9 @@
 #include "volumemonitor.h"
 #include "desktopappinfo.h"
 #include "unixconnection.h"
+#include "unixcredentialsmessage.h"
+#include "unixfdlist.h"
+#include "unixfdmessage.h"
 #include "unixinputstream.h"
 #include "unixoutputstream.h"
 
@@ -80,9 +93,16 @@ extern "C"
 //Declarations of the *_get_type() functions:
 
 GType g_app_launch_context_get_type(void);
+GType g_application_get_type(void);
 GType g_buffered_input_stream_get_type(void);
 GType g_buffered_output_stream_get_type(void);
 GType g_cancellable_get_type(void);
+GType g_credentials_get_type(void);
+GType g_dbus_auth_observer_get_type(void);
+GType g_dbus_connection_get_type(void);
+GType g_dbus_message_get_type(void);
+GType g_dbus_method_invocation_get_type(void);
+GType g_dbus_server_get_type(void);
 GType g_data_input_stream_get_type(void);
 GType g_data_output_stream_get_type(void);
 #ifndef G_OS_WIN32
@@ -117,6 +137,7 @@ GType g_socket_address_get_type(void);
 GType g_socket_address_enumerator_get_type(void);
 GType g_socket_client_get_type(void);
 GType g_socket_connection_get_type(void);
+GType g_socket_control_message_get_type(void);
 GType g_socket_listener_get_type(void);
 GType g_socket_service_get_type(void);
 GType g_tcp_connection_get_type(void);
@@ -125,6 +146,9 @@ GType g_threaded_socket_service_get_type(void);
 #ifndef G_OS_WIN32
 GType g_unix_connection_get_type(void);
 #endif //G_OS_WIN32
+GType g_unix_credentials_message_get_type(void);
+GType g_unix_fd_list_get_type(void);
+GType g_unix_fd_message_get_type(void);
 #ifndef G_OS_WIN32
 GType g_unix_input_stream_get_type(void);
 #endif //G_OS_WIN32
@@ -143,9 +167,16 @@ GQuark g_resolver_error_quark(void);
 //Declarations of the *_Class::wrap_new() methods, instead of including all the private headers:
 
 namespace Gio {  class AppLaunchContext_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gio {  class Application_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class BufferedInputStream_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class BufferedOutputStream_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class Cancellable_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gio {  class Credentials_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gio {  class DBusAuthObserver_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gio {  class DBusConnection_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gio {  class DBusMessage_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gio {  class DBusMethodInvocation_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gio {  class DBusServer_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class DataInputStream_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class DataOutputStream_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 #ifndef G_OS_WIN32
@@ -180,6 +211,7 @@ namespace Gio {  class SocketAddress_Class { public: static Glib::ObjectBase* wr
 namespace Gio {  class SocketAddressEnumerator_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class SocketClient_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class SocketConnection_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gio {  class SocketControlMessage_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class SocketListener_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class SocketService_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Gio {  class TcpConnection_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
@@ -188,6 +220,9 @@ namespace Gio {  class ThreadedSocketService_Class { public: static Glib::Object
 #ifndef G_OS_WIN32
 namespace Gio {  class UnixConnection_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 #endif //G_OS_WIN32
+namespace Gio {  class UnixCredentialsMessage_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gio {  class UnixFDList_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Gio {  class UnixFDMessage_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 #ifndef G_OS_WIN32
 namespace Gio {  class UnixInputStream_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 #endif //G_OS_WIN32
@@ -206,9 +241,16 @@ void wrap_init()
 
 // Map gtypes to gtkmm wrapper-creation functions:
   Glib::wrap_register(g_app_launch_context_get_type(), &Gio::AppLaunchContext_Class::wrap_new);
+  Glib::wrap_register(g_application_get_type(), &Gio::Application_Class::wrap_new);
   Glib::wrap_register(g_buffered_input_stream_get_type(), &Gio::BufferedInputStream_Class::wrap_new);
   Glib::wrap_register(g_buffered_output_stream_get_type(), &Gio::BufferedOutputStream_Class::wrap_new);
   Glib::wrap_register(g_cancellable_get_type(), &Gio::Cancellable_Class::wrap_new);
+  Glib::wrap_register(g_credentials_get_type(), &Gio::Credentials_Class::wrap_new);
+  Glib::wrap_register(g_dbus_auth_observer_get_type(), &Gio::DBusAuthObserver_Class::wrap_new);
+  Glib::wrap_register(g_dbus_connection_get_type(), &Gio::DBusConnection_Class::wrap_new);
+  Glib::wrap_register(g_dbus_message_get_type(), &Gio::DBusMessage_Class::wrap_new);
+  Glib::wrap_register(g_dbus_method_invocation_get_type(), &Gio::DBusMethodInvocation_Class::wrap_new);
+  Glib::wrap_register(g_dbus_server_get_type(), &Gio::DBusServer_Class::wrap_new);
   Glib::wrap_register(g_data_input_stream_get_type(), &Gio::DataInputStream_Class::wrap_new);
   Glib::wrap_register(g_data_output_stream_get_type(), &Gio::DataOutputStream_Class::wrap_new);
 #ifndef G_OS_WIN32
@@ -243,6 +285,7 @@ void wrap_init()
   Glib::wrap_register(g_socket_address_enumerator_get_type(), &Gio::SocketAddressEnumerator_Class::wrap_new);
   Glib::wrap_register(g_socket_client_get_type(), &Gio::SocketClient_Class::wrap_new);
   Glib::wrap_register(g_socket_connection_get_type(), &Gio::SocketConnection_Class::wrap_new);
+  Glib::wrap_register(g_socket_control_message_get_type(), &Gio::SocketControlMessage_Class::wrap_new);
   Glib::wrap_register(g_socket_listener_get_type(), &Gio::SocketListener_Class::wrap_new);
   Glib::wrap_register(g_socket_service_get_type(), &Gio::SocketService_Class::wrap_new);
   Glib::wrap_register(g_tcp_connection_get_type(), &Gio::TcpConnection_Class::wrap_new);
@@ -251,6 +294,9 @@ void wrap_init()
 #ifndef G_OS_WIN32
   Glib::wrap_register(g_unix_connection_get_type(), &Gio::UnixConnection_Class::wrap_new);
 #endif //G_OS_WIN32
+  Glib::wrap_register(g_unix_credentials_message_get_type(), &Gio::UnixCredentialsMessage_Class::wrap_new);
+  Glib::wrap_register(g_unix_fd_list_get_type(), &Gio::UnixFDList_Class::wrap_new);
+  Glib::wrap_register(g_unix_fd_message_get_type(), &Gio::UnixFDMessage_Class::wrap_new);
 #ifndef G_OS_WIN32
   Glib::wrap_register(g_unix_input_stream_get_type(), &Gio::UnixInputStream_Class::wrap_new);
 #endif //G_OS_WIN32
@@ -261,9 +307,16 @@ void wrap_init()
 
   // Register the gtkmm gtypes:
   Gio::AppLaunchContext::get_type();
+  Gio::Application::get_type();
   Gio::BufferedInputStream::get_type();
   Gio::BufferedOutputStream::get_type();
   Gio::Cancellable::get_type();
+  Gio::Credentials::get_type();
+  Gio::DBusAuthObserver::get_type();
+  Gio::DBusConnection::get_type();
+  Gio::DBusMessage::get_type();
+  Gio::DBusMethodInvocation::get_type();
+  Gio::DBusServer::get_type();
   Gio::DataInputStream::get_type();
   Gio::DataOutputStream::get_type();
 #ifndef G_OS_WIN32
@@ -298,6 +351,7 @@ void wrap_init()
   Gio::SocketAddressEnumerator::get_type();
   Gio::SocketClient::get_type();
   Gio::SocketConnection::get_type();
+  Gio::SocketControlMessage::get_type();
   Gio::SocketListener::get_type();
   Gio::SocketService::get_type();
   Gio::TcpConnection::get_type();
@@ -306,6 +360,9 @@ void wrap_init()
 #ifndef G_OS_WIN32
   Gio::UnixConnection::get_type();
 #endif //G_OS_WIN32
+  Gio::UnixCredentialsMessage::get_type();
+  Gio::UnixFDList::get_type();
+  Gio::UnixFDMessage::get_type();
 #ifndef G_OS_WIN32
   Gio::UnixInputStream::get_type();
 #endif //G_OS_WIN32
